@@ -31,7 +31,8 @@ ACTEDProjectSchema = schemata.ATContentTypeSchema.copy() + atapi.Schema((
     atapi.TextField(
         name='description',
         widget=atapi.TextAreaWidget(
-        label=_(u'Project Description')
+        label=_(u'Project Description'),
+        visible={'view': 'hidden', 'edit': 'hidden' }
       ),
       required=False,
       searchable=True
@@ -45,20 +46,20 @@ ACTEDProjectSchema = schemata.ATContentTypeSchema.copy() + atapi.Schema((
         maxlength=20,
         size=20
       ),
-      required=True,
+      required=False,
       searchable=True
     ),
 
-    atapi.StringField(
-        name='projectDonor',
+    atapi.IntegerField(
+        name='projectYear',
         widget=atapi.SelectionWidget(
-        label=_(u'Donor'),
+        label=_(u'Year of Contract Signature'),
         format='select'
       ),
-      vocabulary=ACTED_DONORS,
+      vocabulary=ACTED_YEARS,
       enforceVocabulary=True,
       required=True,
-      searchable=True
+      searchable=False
     ),
 
 
@@ -71,34 +72,40 @@ ACTEDProjectSchema = schemata.ATContentTypeSchema.copy() + atapi.Schema((
       ),
       vocabulary=ACTED_COUNTRIES,
       enforceVocabulary=True,
-      required=True,
+      required=False,
       searchable=True
     ),
 
+
+
+    atapi.StringField(
+        name='projectDonor',
+        widget=atapi.MultiSelectionWidget(
+        label=_(u'Donor'),
+        format='select',
+        size=25
+      ),
+      vocabulary=ACTED_DONORS,
+      enforceVocabulary=True,
+      required=False,
+      searchable=True
+    ),
+
+
+
+
     atapi.StringField(
         name='projectSectors',
         widget=atapi.MultiSelectionWidget(
         label=_(u'Sectors'),
-        format='select'
+        format='select',
+        size='10'
       ),
       vocabulary=ACTED_SECTORS,
       required=False,
       searchable=True
     ),
 
-    atapi.IntegerField(
-        name='projectYear',
-        widget=atapi.SelectionWidget(
-        label=_(u'Year of Contract Signature'),
-        format='select'
-      ),
-#      vocabulary=['2000','2001','2002','2003','2004','2004','2005','2006','2007','2008','2009','2010',],
-      vocabulary=ACTED_YEARS,
-      enforceVocabulary=True,
-      required=True,
-      searchable=False
-    ),
-
     atapi.StringField(
         name='projectBudget',
         widget=atapi.StringWidget(
